@@ -3,7 +3,6 @@ from django.contrib import messages
 from django.contrib.auth.views import LoginView as BaseLoginView
 from django_revision.revision import site_revision
 from edc_dashboard.utils import get_bootstrap_version, get_template_path_with_bootstrap
-from edc_protocol import Protocol
 
 
 class LoginView(BaseLoginView):
@@ -21,7 +20,6 @@ class LoginView(BaseLoginView):
 
     @property
     def extra_context(self):
-        protocol = Protocol()
         try:
             live_system = settings.LIVE_SYSTEM
         except AttributeError:
@@ -34,12 +32,7 @@ class LoginView(BaseLoginView):
             "edc_base_template": get_template_path_with_bootstrap("edc_dashboard/base.html"),
             "DEBUG": settings.DEBUG,
             "ALLOW_PASSWORD_RESET": allow_password_reset,
-            "copyright": protocol.copyright,
-            "disclaimer": protocol.disclaimer,
-            "institution": protocol.institution,
-            "license": protocol.license,
             "revision": site_revision.tag,
-            "project_name": protocol.project_name,
             "live_system": live_system,
             "INDEX_PAGE": getattr(settings, "INDEX_PAGE", None),
             "INDEX_PAGE_LABEL": getattr(settings, "INDEX_PAGE_LABEL", None),
